:mod:`client` -- HPLeftHandClient
=================================

.. automodule:: hplefthandclient.client
   :synopsis: HP LeftHand REST Web client

   .. autoclass:: hplefthandclient.client.HPLeftHandClient(api_url)

      .. automethod:: debug_rest
      .. automethod:: login
      .. automethod:: logout
      .. automethod:: getClusters
      .. automethod:: getCluster
      .. automethod:: getClusterByName
      .. automethod:: getServers
      .. automethod:: getServer
      .. automethod:: getServerByName
      .. automethod:: createServer
      .. automethod:: deleteServer
      .. automethod:: getSnapshots
      .. automethod:: getSnapshot
      .. automethod:: getSnapshotByName
      .. automethod:: createSnapshot
      .. automethod:: deleteSnapshot
      .. automethod:: cloneSnapshot
      .. automethod:: getVolumes
      .. automethod:: getVolume
      .. automethod:: getVolumeByName
      .. automethod:: createVolume
      .. automethod:: deleteVolume
      .. automethod:: modifyVolume
      .. automethod:: cloneVolume
      .. automethod:: addServerAccess
      .. automethod:: removeServerAccess
